summaryrefslogtreecommitdiff
path: root/src/include
diff options
context:
space:
mode:
authorChristian Grothoff <christian@grothoff.org>2022-04-15 11:56:43 +0200
committerChristian Grothoff <christian@grothoff.org>2022-04-15 11:56:43 +0200
commitaf7a94e6e95accef7836d8b18e20097f722747eb (patch)
tree0b15cf799638cc41075d971d8f5de4edd8349173 /src/include
parent094a8cde6bd65d1ff1f85e7e07b669ab566e20ab (diff)
downloadanastasis-af7a94e6e95accef7836d8b18e20097f722747eb.tar.gz
anastasis-af7a94e6e95accef7836d8b18e20097f722747eb.tar.bz2
anastasis-af7a94e6e95accef7836d8b18e20097f722747eb.zip
-server_salt is now provider_salt
Diffstat (limited to 'src/include')
-rw-r--r--src/include/anastasis_crypto_lib.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/include/anastasis_crypto_lib.h b/src/include/anastasis_crypto_lib.h
index da60630..648a8eb 100644
--- a/src/include/anastasis_crypto_lib.h
+++ b/src/include/anastasis_crypto_lib.h
@@ -301,13 +301,13 @@ ANASTASIS_hash_answer (uint64_t code,
* data.
*
* @param id_data JSON encoded data, which contains the raw user secret
* @param server_salt salt from the server (escrow provider)
* @param[out] id reference to the id which was created
*/
void
ANASTASIS_CRYPTO_user_identifier_derive (
const json_t *id_data,
- const struct ANASTASIS_CRYPTO_ProviderSaltP *server_salt,
+ const struct ANASTASIS_CRYPTO_ProviderSaltP *provider_salt,
struct ANASTASIS_CRYPTO_UserIdentifierP *id);
@@ -301,13 +301,13 @@ ANASTASIS_hash_answer (uint64_t code,
*
* @param id_data JSON encoded data, which contains the raw user secret
- * @param server_salt salt from the server (escrow provider)
+ * @param provider_salt salt from the server (escrow provider)
* @param[out] id reference to the id which was created
*/